# Generated by Django 4.1.5 on 2023-07-20 17:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("inventory", "0004_alter_category_id_alter_item_id_and_more"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="PTAO",
            new_name="Account",
        ),
        migrations.AlterModelOptions(
            name="account",
            options={
                "ordering": ["code"],
                "verbose_name": "Account",
                "verbose_name_plural": "Accounts",
            },
        ),
        migrations.AlterModelOptions(
            name="order",
            options={"ordering": ["-created"]},
        ),
    ]
