# Generated by Django 4.1.5 on 2023-07-21 18:17
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("inventory", "0007_remove_duplicates"),
    ]

    operations = [
        migrations.AlterField(
            model_name="category",
            name="name",
            field=models.CharField(max_length=45, unique=True),
        ),
        migrations.AlterField(
            model_name="manufacturer",
            name="name",
            field=models.CharField(max_length=64, unique=True),
        ),
        migrations.AlterField(
            model_name="order",
            name="ordered",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="orderitem",
            name="reconciled",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="unit",
            name="name",
            field=models.CharField(max_length=45, unique=True),
        ),
        migrations.AlterField(
            model_name="vendor",
            name="name",
            field=models.CharField(max_length=64, unique=True),
        ),
        migrations.AddConstraint(
            model_name="item",
            constraint=models.UniqueConstraint(
                fields=("vendor", "catalog"), name="unique_vendor_catalog_number"
            ),
        ),
    ]
