{% extends "base_view.html" %}
{% load widget_tweaks %}

{% block title %} meliza-lab : mark order as placed  {% endblock %}

{% block content %}

<div class="panel panel-default">
  <div class="panel-heading">
    <h3 class="panel-title">Remove item from order</h3>
  </div>
  <div class="panel-body">
    <form action="{% url 'inventory:mark_order_placed' object.id %}" class="form-horizontal" method="post" role="form">
      {% csrf_token %}
      <p>Are you sure you want to mark the in-progress order <strong>{{object.order.name}}</strong> as placed?</p>

      <div class="form-group">
        <div class="col-sm-10">
          <button type="submit" name="confirm" class="btn btn-default">Confirm</button>
        </div>
      </div>

    </form>
  </div>
</div>

{% endblock %}
